@@ -6,7 +6,7 @@ bosclust <- function(x=matrix(0,nrow=1,ncol=1), idx_list=c(1), kr, init,
 	res <- clust(xMat=x, myList=idx_list, kr, init, nbSEM, nbSEMburn, nbindmini, 
 				m=m, percentRandomB=percentRandomB, seed=seed)
 	if(length(res@icl)==0){
-		warning('Error: probably empty clusters')
+		warning('The algorithm found a spurious solution with empty clusters. You can: 1) Run the algorithm with another type of initialisation, 2) If you run the algorithm with init to "random" or "randomBurnin", running it again will change the initialisation , 3) Run the algorithm with a smaller argument kr.')
 	}
 	return(res)
 }
\ No newline at end of file
