@@ -7,7 +7,7 @@ boscoclust <- function(x=matrix(0,nrow=1,ncol=1), idx_list=c(1),
 	res <- coclust(xMat=x, myList=idx_list, kr, kc, init, nbSEM, nbSEMburn, 
 		nbRepeat, nbindmini, m=m, percentRandomB=percentRandomB, seed=seed)
 	if(length(res@icl)==0){
-		warning('Error: probably empty clusters')
+		warning('The algorithm found a spurious solution with empty clusters. You can: 1) Run the algorithm with another type of initialisation, 2) If you run the algorithm with init to "random" or "randomBurnin", running it again will change the initialisation , 3) Run the algorithm with a smaller argument kr and/or kc.')
 	}
 	return(res)
 }
\ No newline at end of file
